.. image:: https://raw.githubusercontent.com/cenk/kuyruk/master/docs/_static/lemur.png
   :alt: Kuyruk Logo

Kuyruk
======

.. image:: https://travis-ci.org/cenk/kuyruk.png
   :target: https://travis-ci.org/cenk/kuyruk

.. image:: https://coveralls.io/repos/cenk/kuyruk/badge.png?branch=master
   :target: https://coveralls.io/r/cenk/kuyruk?branch=master

Kuyruk is a simple and easy way of distributing tasks to run on servers.

It uses `RabbitMQ <http://www.rabbitmq.com>`_ as message broker and
depends on `amqp <http://amqp.readthedocs.org/>`_
which is a pure-Python RabbitMQ client library.
Compatible with Python 2.7+ and 3.4+.


Where is the documentation?
---------------------------
Here it is: http://kuyruk.readthedocs.org
